==> lessSEM_1.4.16.tar.gz: lessSEM/R/class-misc.R <==
#' Wrapper for C++ module. See ?lessSEM::istaScadGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaScadGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::bfgsEnetSEM
#' @keywords internal
setClass("Rcpp_bfgsEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::bfgsEnetMgSEM
#' @keywords internal
setClass("Rcpp_bfgsEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMcpGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaMcpGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::istaEnetSEM
#' @keywords internal
setClass("Rcpp_istaEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::istaEnetMgSEM
#' @keywords internal
setClass("Rcpp_istaEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1GeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaCappedL1GeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1GeneralPurpose
#' @keywords internal
setClass("Rcpp_istaCappedL1GeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::istaEnetGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaEnetGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaLspGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaLspGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::istaEnetGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaEnetGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetSEM
#' @keywords internal
setClass("Rcpp_glmnetEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetMgSEM
#' @keywords internal
setClass("Rcpp_glmnetEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMcpSEM
#' @keywords internal
setClass("Rcpp_istaMcpSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMcpMgSEM
#' @keywords internal
setClass("Rcpp_istaMcpMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaLSPSEM
#' @keywords internal
setClass("Rcpp_istaLSPSEM")

#' Wrapper for C++ module. See ?lessSEM::istaLSPMgSEM
#' @keywords internal
setClass("Rcpp_istaLSPMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaScadSEM
#' @keywords internal
setClass("Rcpp_istaScadSEM")

#' Wrapper for C++ module. See ?lessSEM::istaScadMgSEM
#' @keywords internal
setClass("Rcpp_istaScadMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaScadGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaScadGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaMcpGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaMcpGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaLspGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaLspGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1SEM
#' @keywords internal
setClass("Rcpp_istaCappedL1SEM")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1MgSEM
#' @keywords internal
setClass("Rcpp_istaCappedL1mgSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetGeneralPurpose
#' @keywords internal
setClass("Rcpp_glmnetEnetGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_glmnetEnetGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaEnetSEM
#' @keywords internal
setClass("Rcpp_istaEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::istaEnetMgSEM
#' @keywords internal
setClass("Rcpp_istaEnetMgSEM")



#' Wrapper for C++ module. See ?lessSEM::istaMixedPenaltySEM
#' @keywords internal
setClass("Rcpp_istaMixedPenaltySEM")

#' Wrapper for C++ module. See ?lessSEM::istaMixedPenaltymgSEM
#' @keywords internal
setClass("Rcpp_istaMixedPenaltymgSEM")

==> lessSEM_1.5.6.tar.gz: lessSEM/R/class-misc.R <==
#' Wrapper for C++ module. See ?lessSEM::istaScadGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaScadGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::bfgsEnetSEM
#' @keywords internal
setClass("Rcpp_bfgsEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::bfgsEnetMgSEM
#' @keywords internal
setClass("Rcpp_bfgsEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMcpGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaMcpGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::istaEnetSEM
#' @keywords internal
setClass("Rcpp_istaEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::istaEnetMgSEM
#' @keywords internal
setClass("Rcpp_istaEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1GeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaCappedL1GeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1GeneralPurpose
#' @keywords internal
setClass("Rcpp_istaCappedL1GeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::istaEnetGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaEnetGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaLspGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaLspGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::istaEnetGeneralPurpose
#' @keywords internal
setClass("Rcpp_istaEnetGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetSEM
#' @keywords internal
setClass("Rcpp_glmnetEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetMgSEM
#' @keywords internal
setClass("Rcpp_glmnetEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMcpSEM
#' @keywords internal
setClass("Rcpp_istaMcpSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMcpMgSEM
#' @keywords internal
setClass("Rcpp_istaMcpMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaLSPSEM
#' @keywords internal
setClass("Rcpp_istaLSPSEM")

#' Wrapper for C++ module. See ?lessSEM::istaLSPMgSEM
#' @keywords internal
setClass("Rcpp_istaLSPMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaScadSEM
#' @keywords internal
setClass("Rcpp_istaScadSEM")

#' Wrapper for C++ module. See ?lessSEM::istaScadMgSEM
#' @keywords internal
setClass("Rcpp_istaScadMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaScadGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaScadGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaMcpGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaMcpGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaLspGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_istaLspGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1SEM
#' @keywords internal
setClass("Rcpp_istaCappedL1SEM")

#' Wrapper for C++ module. See ?lessSEM::istaCappedL1MgSEM
#' @keywords internal
setClass("Rcpp_istaCappedL1mgSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetGeneralPurpose
#' @keywords internal
setClass("Rcpp_glmnetEnetGeneralPurpose")

#' Wrapper for C++ module. See ?lessSEM::glmnetEnetGeneralPurposeCpp
#' @keywords internal
setClass("Rcpp_glmnetEnetGeneralPurposeCpp")

#' Wrapper for C++ module. See ?lessSEM::istaEnetSEM
#' @keywords internal
setClass("Rcpp_istaEnetSEM")

#' Wrapper for C++ module. See ?lessSEM::istaEnetMgSEM
#' @keywords internal
setClass("Rcpp_istaEnetMgSEM")

#' Wrapper for C++ module. See ?lessSEM:::glmnetScadSEM
#' @keywords internal
setClass("Rcpp_glmnetScadSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetScadMgSEM
#' @keywords internal
setClass("Rcpp_glmnetScadMgSEM")

#' Wrapper for C++ module. See ?lessSEM:::glmnetCappedL1SEM
#' @keywords internal
setClass("Rcpp_glmnetCappedL1SEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetCappedL1MgSEM
#' @keywords internal
setClass("Rcpp_glmnetCappedL1MgSEM")

#' Wrapper for C++ module. See ?lessSEM:::glmnetMcpSEM
#' @keywords internal
setClass("Rcpp_glmnetMcpSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetMcpMgSEM
#' @keywords internal
setClass("Rcpp_glmnetMcpMgSEM")

#' Wrapper for C++ module. See ?lessSEM:::glmnetLspSEM
#' @keywords internal
setClass("Rcpp_glmnetLspSEM")

#' Wrapper for C++ module. See ?lessSEM::glmnetLspMgSEM
#' @keywords internal
setClass("Rcpp_glmnetLspMgSEM")

#' Wrapper for C++ module. See ?lessSEM::istaMixedPenaltySEM
#' @keywords internal
setClass("Rcpp_istaMixedPenaltySEM")

#' Wrapper for C++ module. See ?lessSEM::istaMixedPenaltymgSEM
#' @keywords internal
setClass("Rcpp_istaMixedPenaltymgSEM")
